==> pmd-1.17-sources.jar: hudson/plugins/pmd/Messages.java <==
// CHECKSTYLE:OFF

package hudson.plugins.pmd;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;

@SuppressWarnings({
    "",
    "PMD"
})
public class Messages {

    private final static ResourceBundleHolder holder = new ResourceBundleHolder(Messages.class);

    /**
     * New PMD Warnings
     * 
     */
    public static String PMD_NewWarnings_Detail_header() {
        return holder.format("PMD.NewWarnings.Detail.header");
    }

    /**
     * New PMD Warnings
     * 
     */
    public static Localizable _PMD_NewWarnings_Detail_header() {
        return new Localizable(holder, "PMD.NewWarnings.Detail.header");
    }

    /**
     * Still one day before reaching the previous zero warnings highscore.
     * 
     */
    public static String PMD_ResultAction_OneNoHighScore() {
        return holder.format("PMD.ResultAction.OneNoHighScore");
    }

    /**
     * Still one day before reaching the previous zero warnings highscore.
     * 
     */
    public static Localizable _PMD_ResultAction_OneNoHighScore() {
        return new Localizable(holder, "PMD.ResultAction.OneNoHighScore");
    }

    /**
     * New zero warnings highscore: no PMD warnings since yesterday!
     * 
     */
    public static String PMD_ResultAction_OneHighScore() {
        return holder.format("PMD.ResultAction.OneHighScore");
    }

    /**
     * New zero warnings highscore: no PMD warnings since yesterday!
     * 
     */
    public static Localizable _PMD_ResultAction_OneHighScore() {
        return new Localizable(holder, "PMD.ResultAction.OneHighScore");
    }

    /**
     * {0} fixed warnings
     * 
     */
    public static String PMD_ResultAction_MultipleFixedWarnings(Object arg1) {
        return holder.format("PMD.ResultAction.MultipleFixedWarnings", arg1);
    }

    /**
     * {0} fixed warnings
     * 
     */
    public static Localizable _PMD_ResultAction_MultipleFixedWarnings(Object arg1) {
        return new Localizable(holder, "PMD.ResultAction.MultipleFixedWarnings", arg1);
    }

    /**
     * No warnings since build {0}.
     * 
     */
    public static String PMD_ResultAction_NoWarningsSince(Object arg1) {
        return holder.format("PMD.ResultAction.NoWarningsSince", arg1);
    }

    /**
     * No warnings since build {0}.
     * 
     */
    public static Localizable _PMD_ResultAction_NoWarningsSince(Object arg1) {
        return new Localizable(holder, "PMD.ResultAction.NoWarningsSince", arg1);
    }

    /**
     * Still {0} days before reaching the previous zero warnings highscore.
     * 
     */
    public static String PMD_ResultAction_MultipleNoHighScore(Object arg1) {
        return holder.format("PMD.ResultAction.MultipleNoHighScore", arg1);
    }

    /**
     * Still {0} days before reaching the previous zero warnings highscore.
     * 
     */
    public static Localizable _PMD_ResultAction_MultipleNoHighScore(Object arg1) {
        return new Localizable(holder, "PMD.ResultAction.MultipleNoHighScore", arg1);
    }

    /**
     * PMD Warnings
     * 
     */
    public static String PMD_ProjectAction_Name() {
        return holder.format("PMD.ProjectAction.Name");
    }

    /**
     * PMD Warnings
     * 
     */
    public static Localizable _PMD_ProjectAction_Name() {
        return new Localizable(holder, "PMD.ProjectAction.Name");
    }

    /**
     * New zero warnings highscore: no PMD warnings since {0} days!
     * 
     */
    public static String PMD_ResultAction_MultipleHighScore(Object arg1) {
        return holder.format("PMD.ResultAction.MultipleHighScore", arg1);
    }

    /**
     * New zero warnings highscore: no PMD warnings since {0} days!
     * 
     */
    public static Localizable _PMD_ResultAction_MultipleHighScore(Object arg1) {
        return new Localizable(holder, "PMD.ResultAction.MultipleHighScore", arg1);
    }

    /**
     *  1 new warning
     * 
     */
    public static String PMD_ResultAction_OneNewWarning() {
        return holder.format("PMD.ResultAction.OneNewWarning");
    }

    /**
     *  1 new warning
     * 
     */
    public static Localizable _PMD_ResultAction_OneNewWarning() {
        return new Localizable(holder, "PMD.ResultAction.OneNewWarning");
    }

    /**
     * Publish PMD Analysis Results
     * 
     */
    public static String PMD_Publisher_Name() {
        return holder.format("PMD.Publisher.Name");
    }

    /**
     * Publish PMD Analysis Results
     * 
     */
    public static Localizable _PMD_Publisher_Name() {
        return new Localizable(holder, "PMD.Publisher.Name");
    }

    /**
     * PMD Trend
     * 
     */
    public static String PMD_Trend_Name() {
        return holder.format("PMD.Trend.Name");
    }

    /**
     * PMD Trend
     * 
     */
    public static Localizable _PMD_Trend_Name() {
        return new Localizable(holder, "PMD.Trend.Name");
    }

    /**
     * PMD: %d warnings found (%d %s, %d %s, %d %s).
     * 
     */
    public static String PMD_ResultAction_HealthReportMultipleItem() {
        return holder.format("PMD.ResultAction.HealthReportMultipleItem");
    }

    /**
     * PMD: %d warnings found (%d %s, %d %s, %d %s).
     * 
     */
    public static Localizable _PMD_ResultAction_HealthReportMultipleItem() {
        return new Localizable(holder, "PMD.ResultAction.HealthReportMultipleItem");
    }

    /**
     * in {0} PMD files.
     * 
     */
    public static String PMD_ResultAction_MultipleFiles(Object arg1) {
        return holder.format("PMD.ResultAction.MultipleFiles", arg1);
    }

    /**
     * in {0} PMD files.
     * 
     */
    public static Localizable _PMD_ResultAction_MultipleFiles(Object arg1) {
        return new Localizable(holder, "PMD.ResultAction.MultipleFiles", arg1);
    }

    /**
     * PMD Warnings
     * 
     */
    public static String PMD_Detail_header() {
        return holder.format("PMD.Detail.header");
    }

    /**
     * PMD Warnings
     * 
     */
    public static Localizable _PMD_Detail_header() {
        return new Localizable(holder, "PMD.Detail.header");
    }

    /**
     * Fixed PMD Warnings
     * 
     */
    public static String PMD_FixedWarnings_Detail_header() {
        return holder.format("PMD.FixedWarnings.Detail.header");
    }

    /**
     * Fixed PMD Warnings
     * 
     */
    public static Localizable _PMD_FixedWarnings_Detail_header() {
        return new Localizable(holder, "PMD.FixedWarnings.Detail.header");
    }

    /**
     * PMD: 1 warning found.
     * 
     */
    public static String PMD_ResultAction_HealthReportSingleItem() {
        return holder.format("PMD.ResultAction.HealthReportSingleItem");
    }

    /**
     * PMD: 1 warning found.
     * 
     */
    public static Localizable _PMD_ResultAction_HealthReportSingleItem() {
        return new Localizable(holder, "PMD.ResultAction.HealthReportSingleItem");
    }

    /**
     * {0} warnings
     * 
     */
    public static String PMD_ResultAction_MultipleWarnings(Object arg1) {
        return holder.format("PMD.ResultAction.MultipleWarnings", arg1);
    }

    /**
     * {0} warnings
     * 
     */
    public static Localizable _PMD_ResultAction_MultipleWarnings(Object arg1) {
        return new Localizable(holder, "PMD.ResultAction.MultipleWarnings", arg1);
    }

    /**
     * in 1 PMD file.
     * 
     */
    public static String PMD_ResultAction_OneFile() {
        return holder.format("PMD.ResultAction.OneFile");
    }

    /**
     * in 1 PMD file.
     * 
     */
    public static Localizable _PMD_ResultAction_OneFile() {
        return new Localizable(holder, "PMD.ResultAction.OneFile");
    }

    /**
     *  1 fixed warning
     * 
     */
    public static String PMD_ResultAction_OneFixedWarning() {
        return holder.format("PMD.ResultAction.OneFixedWarning");
    }

    /**
     *  1 fixed warning
     * 
     */
    public static Localizable _PMD_ResultAction_OneFixedWarning() {
        return new Localizable(holder, "PMD.ResultAction.OneFixedWarning");
    }

    /**
     *  1 warning
     * 
     */
    public static String PMD_ResultAction_OneWarning() {
        return holder.format("PMD.ResultAction.OneWarning");
    }

    /**
     *  1 warning
     * 
     */
    public static Localizable _PMD_ResultAction_OneWarning() {
        return new Localizable(holder, "PMD.ResultAction.OneWarning");
    }

    /**
     * {0} new warnings
     * 
     */
    public static String PMD_ResultAction_MultipleNewWarnings(Object arg1) {
        return holder.format("PMD.ResultAction.MultipleNewWarnings", arg1);
    }

    /**
     * {0} new warnings
     * 
     */
    public static Localizable _PMD_ResultAction_MultipleNewWarnings(Object arg1) {
        return new Localizable(holder, "PMD.ResultAction.MultipleNewWarnings", arg1);
    }

}

==> pmd-1.20-sources.jar: hudson/plugins/pmd/Messages.java <==
// CHECKSTYLE:OFF

package hudson.plugins.pmd;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;

@SuppressWarnings({
    "",
    "PMD"
})
public class Messages {

    private final static ResourceBundleHolder holder = new ResourceBundleHolder(Messages.class);

    /**
     * New PMD Warnings
     * 
     */
    public static String PMD_NewWarnings_Detail_header() {
        return holder.format("PMD.NewWarnings.Detail.header");
    }

    /**
     * New PMD Warnings
     * 
     */
    public static Localizable _PMD_NewWarnings_Detail_header() {
        return new Localizable(holder, "PMD.NewWarnings.Detail.header");
    }

    /**
     * Still one day before reaching the previous zero warnings highscore.
     * 
     */
    public static String PMD_ResultAction_OneNoHighScore() {
        return holder.format("PMD.ResultAction.OneNoHighScore");
    }

    /**
     * Still one day before reaching the previous zero warnings highscore.
     * 
     */
    public static Localizable _PMD_ResultAction_OneNoHighScore() {
        return new Localizable(holder, "PMD.ResultAction.OneNoHighScore");
    }

    /**
     * New zero warnings highscore: no PMD warnings since yesterday!
     * 
     */
    public static String PMD_ResultAction_OneHighScore() {
        return holder.format("PMD.ResultAction.OneHighScore");
    }

    /**
     * New zero warnings highscore: no PMD warnings since yesterday!
     * 
     */
    public static Localizable _PMD_ResultAction_OneHighScore() {
        return new Localizable(holder, "PMD.ResultAction.OneHighScore");
    }

    /**
     * {0} fixed warnings
     * 
     */
    public static String PMD_ResultAction_MultipleFixedWarnings(Object arg1) {
        return holder.format("PMD.ResultAction.MultipleFixedWarnings", arg1);
    }

    /**
     * {0} fixed warnings
     * 
     */
    public static Localizable _PMD_ResultAction_MultipleFixedWarnings(Object arg1) {
        return new Localizable(holder, "PMD.ResultAction.MultipleFixedWarnings", arg1);
    }

    /**
     * No warnings since build {0}.
     * 
     */
    public static String PMD_ResultAction_NoWarningsSince(Object arg1) {
        return holder.format("PMD.ResultAction.NoWarningsSince", arg1);
    }

    /**
     * No warnings since build {0}.
     * 
     */
    public static Localizable _PMD_ResultAction_NoWarningsSince(Object arg1) {
        return new Localizable(holder, "PMD.ResultAction.NoWarningsSince", arg1);
    }

    /**
     * Still {0} days before reaching the previous zero warnings highscore.
     * 
     */
    public static String PMD_ResultAction_MultipleNoHighScore(Object arg1) {
        return holder.format("PMD.ResultAction.MultipleNoHighScore", arg1);
    }

    /**
     * Still {0} days before reaching the previous zero warnings highscore.
     * 
     */
    public static Localizable _PMD_ResultAction_MultipleNoHighScore(Object arg1) {
        return new Localizable(holder, "PMD.ResultAction.MultipleNoHighScore", arg1);
    }

    /**
     * PMD Warnings
     * 
     */
    public static String PMD_ProjectAction_Name() {
        return holder.format("PMD.ProjectAction.Name");
    }

    /**
     * PMD Warnings
     * 
     */
    public static Localizable _PMD_ProjectAction_Name() {
        return new Localizable(holder, "PMD.ProjectAction.Name");
    }

    /**
     * New zero warnings highscore: no PMD warnings since {0} days!
     * 
     */
    public static String PMD_ResultAction_MultipleHighScore(Object arg1) {
        return holder.format("PMD.ResultAction.MultipleHighScore", arg1);
    }

    /**
     * New zero warnings highscore: no PMD warnings since {0} days!
     * 
     */
    public static Localizable _PMD_ResultAction_MultipleHighScore(Object arg1) {
        return new Localizable(holder, "PMD.ResultAction.MultipleHighScore", arg1);
    }

    /**
     *  1 new warning
     * 
     */
    public static String PMD_ResultAction_OneNewWarning() {
        return holder.format("PMD.ResultAction.OneNewWarning");
    }

    /**
     *  1 new warning
     * 
     */
    public static Localizable _PMD_ResultAction_OneNewWarning() {
        return new Localizable(holder, "PMD.ResultAction.OneNewWarning");
    }

    /**
     * Publish PMD Analysis Results
     * 
     */
    public static String PMD_Publisher_Name() {
        return holder.format("PMD.Publisher.Name");
    }

    /**
     * Publish PMD Analysis Results
     * 
     */
    public static Localizable _PMD_Publisher_Name() {
        return new Localizable(holder, "PMD.Publisher.Name");
    }

    /**
     * PMD Trend
     * 
     */
    public static String PMD_Trend_Name() {
        return holder.format("PMD.Trend.Name");
    }

    /**
     * PMD Trend
     * 
     */
    public static Localizable _PMD_Trend_Name() {
        return new Localizable(holder, "PMD.Trend.Name");
    }

    /**
     * Checkstyle: {0} warnings found.
     * 
     */
    public static String PMD_ResultAction_HealthReportMultipleItem(Object arg1) {
        return holder.format("PMD.ResultAction.HealthReportMultipleItem", arg1);
    }

    /**
     * Checkstyle: {0} warnings found.
     * 
     */
    public static Localizable _PMD_ResultAction_HealthReportMultipleItem(Object arg1) {
        return new Localizable(holder, "PMD.ResultAction.HealthReportMultipleItem", arg1);
    }

    /**
     * Checkstyle: no warnings found.
     * 
     */
    public static String PMD_ResultAction_HealthReportNoItem() {
        return holder.format("PMD.ResultAction.HealthReportNoItem");
    }

    /**
     * Checkstyle: no warnings found.
     * 
     */
    public static Localizable _PMD_ResultAction_HealthReportNoItem() {
        return new Localizable(holder, "PMD.ResultAction.HealthReportNoItem");
    }

    /**
     * in {0} PMD files.
     * 
     */
    public static String PMD_ResultAction_MultipleFiles(Object arg1) {
        return holder.format("PMD.ResultAction.MultipleFiles", arg1);
    }

    /**
     * in {0} PMD files.
     * 
     */
    public static Localizable _PMD_ResultAction_MultipleFiles(Object arg1) {
        return new Localizable(holder, "PMD.ResultAction.MultipleFiles", arg1);
    }

    /**
     * PMD Warnings
     * 
     */
    public static String PMD_Detail_header() {
        return holder.format("PMD.Detail.header");
    }

    /**
     * PMD Warnings
     * 
     */
    public static Localizable _PMD_Detail_header() {
        return new Localizable(holder, "PMD.Detail.header");
    }

    /**
     * Fixed PMD Warnings
     * 
     */
    public static String PMD_FixedWarnings_Detail_header() {
        return holder.format("PMD.FixedWarnings.Detail.header");
    }

    /**
     * Fixed PMD Warnings
     * 
     */
    public static Localizable _PMD_FixedWarnings_Detail_header() {
        return new Localizable(holder, "PMD.FixedWarnings.Detail.header");
    }

    /**
     * Checkstyle: one warning found.
     * 
     */
    public static String PMD_ResultAction_HealthReportSingleItem() {
        return holder.format("PMD.ResultAction.HealthReportSingleItem");
    }

    /**
     * Checkstyle: one warning found.
     * 
     */
    public static Localizable _PMD_ResultAction_HealthReportSingleItem() {
        return new Localizable(holder, "PMD.ResultAction.HealthReportSingleItem");
    }

    /**
     * {0} warnings
     * 
     */
    public static String PMD_ResultAction_MultipleWarnings(Object arg1) {
        return holder.format("PMD.ResultAction.MultipleWarnings", arg1);
    }

    /**
     * {0} warnings
     * 
     */
    public static Localizable _PMD_ResultAction_MultipleWarnings(Object arg1) {
        return new Localizable(holder, "PMD.ResultAction.MultipleWarnings", arg1);
    }

    /**
     * in 1 PMD file.
     * 
     */
    public static String PMD_ResultAction_OneFile() {
        return holder.format("PMD.ResultAction.OneFile");
    }

    /**
     * in 1 PMD file.
     * 
     */
    public static Localizable _PMD_ResultAction_OneFile() {
        return new Localizable(holder, "PMD.ResultAction.OneFile");
    }

    /**
     *  1 fixed warning
     * 
     */
    public static String PMD_ResultAction_OneFixedWarning() {
        return holder.format("PMD.ResultAction.OneFixedWarning");
    }

    /**
     *  1 fixed warning
     * 
     */
    public static Localizable _PMD_ResultAction_OneFixedWarning() {
        return new Localizable(holder, "PMD.ResultAction.OneFixedWarning");
    }

    /**
     *  1 warning
     * 
     */
    public static String PMD_ResultAction_OneWarning() {
        return holder.format("PMD.ResultAction.OneWarning");
    }

    /**
     *  1 warning
     * 
     */
    public static Localizable _PMD_ResultAction_OneWarning() {
        return new Localizable(holder, "PMD.ResultAction.OneWarning");
    }

    /**
     * {0} new warnings
     * 
     */
    public static String PMD_ResultAction_MultipleNewWarnings(Object arg1) {
        return holder.format("PMD.ResultAction.MultipleNewWarnings", arg1);
    }

    /**
     * {0} new warnings
     * 
     */
    public static Localizable _PMD_ResultAction_MultipleNewWarnings(Object arg1) {
        return new Localizable(holder, "PMD.ResultAction.MultipleNewWarnings", arg1);
    }

}
